<template>
  <el-dialog
    :close-on-click-modal="false"
    :visible.sync="editDialogVisible"
    width="623px"
    class="add-event-dialog"
    @close="shutdown"
  >
    <div slot="title" class="tac drawerHeader">
      <span> {{title}}组件</span>
    </div>
  
    <div class="dialog-content-box">
      <el-table
      v-if="isTableShow"
        :header-cell-style="{ background: '#f1f3f8', color: '#000009' }"
        ref="multipleTable"
        :data="BomTableData"
        height="100%"
        tooltip-effect="dark"
      >
        <el-table-column prop="unit" label="类别">
          <template slot-scope="scope">
          <el-input v-model="scope.row.name"></el-input>
          </template>
        </el-table-column>
        <el-table-column prop="createdAt" label="设为默认">
          <template slot-scope="scope">
          <el-switch @change="switchChange(scope,scope.row.isDefault)"  v-model="scope.row.isDefault"></el-switch>
          </template>
    
        </el-table-column>
        <el-table-column label="操作" width="100">
          <template slot-scope="scope">
            <!-- <i class="el-icon-top" id="iconStyle"></i>
           <i class="el-icon-bottom"  id="iconStyle"></i> -->
            <i class="el-icon-delete" id="iconStyle" @click="handleDelete(scope.row.id)"></i>
          </template>
        </el-table-column>
      </el-table>
    </div>
      <div slot="footer" class="drawerFooter">
        <el-button
          @click="handleAdd()"
          style="margin-left: 16px; color: #fff; background-color: #ee790c"
          >新增</el-button
        >
        <el-button @click="shutdown">取消</el-button
        ><el-button
          type="primary"
          @click="handleConfirmSave()"
          style="margin-left: 16px; color: #fff; background-color: #2a78fb"
          >确定</el-button
        >
      </div>
    
  </el-dialog>
</template>

<script>

import { getCodeStandardList } from "@/api/basic/standard";
import {
  NetworkCard,
  getMiniDictList,
  addMiniDict, 
  deleteMiniDict,
  updateMiniDict,
  sendProcessParams
} from "@/api/home/index";  
export default {
  name: "",
  props: {
    title:{
      type:String,
    },
    editRow: {
      type: Object,
      default: () => {
        return {};
      },
    },
    workList:{
      type:Array,
    }
  },
  data() {
    return {
      editDialogVisible: false,
      isTableShow:true,
      form: {},
      BomTableData: [1],
      work: 1,
      flag: "add",
      obj: { name: "", page: 0, pageSize: 0, type: "物料编码" },
      inputValue: [],
      codenumer: 0, //每次输入的编码
      codenumberList: [], //整条编码
      sum: 0,
      explain: "",
      Tabs: "msg",
      tableData: [
        {
          date: "PEBU",
          name: "PE布",
          number: "21",
          unit: "吨",
        },
      ],
      rules: {
        id: [{ required: true, message: "请输入物料编码", trigger: "blur" }],
        name: [
          { required: true, message: "请输入物料名称", trigger: "blur" },
          
        ],
        specs: [{ required: true, message: "请输入物料规格", trigger: "blur" }],
        type: [{ required: true, message: "请输入物料型号", trigger: "blur" }],
        amount: [
          {
            required: true,
            message: "请输入数量",
            trigger: "blur",
          },
        ],
        unit: [
          {
            required: true,
            message: "请输入单位",
            trigger: "blur",
          },
        ],
        model: [
          { required: true, message: "请选择物料类型", trigger: "change" },
        ],
      },
    };
  },
  watch: {
    editDialogVisible(newVal){
      if(newVal){
       this.BomTableData=  JSON.parse(
        JSON.stringify(this.workList))
      }
    },
    workList(newVal){
      this.BomTableData=JSON.parse(
        JSON.stringify(this.workList))
    }  
  },
  mounted() {
  },
  methods: {
    handleAdd() {
      this.BomTableData.push({name:'',isDefault:false});
    },
    handleDelete(id) {
      
      this.BomTableData=this.BomTableData.filter(i=>{
        return i.id!=id
      })

    },
    async getCodeStandardList() {
      const res = await getCodeStandardList(this.obj);
      this.codenumer = [];
      this.sum = 0;
      this.explain = "";
      const { rules = [] } = res.data[0];
      rules.forEach((item, index) => {
        this.codenumer.push(item.length);
        this.sum++;
        // index - 1
        //   ? (this.explain += item.name + "/")
        //   : (this.explain += item.name);
        this.explain += item.name + (index === rules.length - 1 ? "" : "/");
      });
      this.$forceUpdate();
    },
    codeList(val) {
      console.log(val, "codeList");
      this.inputValue = val;
      this.codenumberList = val.toString();
      console.log(this.codenumberList.replace(/,/g, ""));
    },
    switchChange(scope,val){
      let arr=[]
      for(let i in this.BomTableData){
        if(this.BomTableData[i].isDefault){
          arr.push(i)
        }
      }
      if(arr.length>1){
        this.$message({
          message: '只能设一个为默认',
          type: "warning",
        });
        scope.row.isDefault=!val
      }
    },
    handleConfirmSave() {
      let arr=[]
      for(let i in this.BomTableData){
        if(this.BomTableData[i].isDefault){
          arr.push(i)
        }
      }
      if(arr.length>1){
        this.$message({
          message: '只能设一个为默认',
          type: "warning",
        });
      }else{ 
        this.$emit('handleConfirmSave',this.BomTableData)
      }
    },
   
    shutdown() {
      this.editDialogVisible = false;
      
    },
  },
};
</script>

<style lang="scss" scoped>
.dialog-content-box {
  height:400px;
  .form-item {
    width: 65%;
  }
  .form-item2 {
    width: calc(50% - 5px);
    float:left;
   
  }
}
  #iconStyle {
    font-size: 20px !important;
  }
 

::v-deep .el-form {
  width: 389px;
  .input-box .input-content input {
    margin: 0;
    margin-right: 3px;
  }
  .el-input__inner,
  .el-textarea__inner {
    line-height: 18px;
    font-family: PingFangSC;
  }
}
::v-deep .el-tabs__header {
  border: none;
  .el-tabs__nav {
    border: none;
   
  }
}
::v-deep .el-form-item__content {
  width: 263px;
  .input-box {
    width: 263px;
  }
}
::v-deep .el-form-item__label {
  font-size: 13px !important;
  color: #000;
  font-family: PingFangSC;
  text-align: center !important;
  width: 60px;
}
::v-deep .input-box .input-content input {
  width: 23px;
  height: 26px;
  border-color: rgba(0, 0, 0, 0.1);
  font-family: PingFangSC;
}
::v-deep .el-icon-minus {
  width: 13px !important;
  height: 26px !important;
  line-height: 38px !important;
  color: #e5e5e5;
  font-size: 13px;
}
::v-deep .el-input__inner {
  font-size: 13px !important;
  color: rgba(0, 0, 0, 0.9);
}
::v-deep .el-input__inner::placeholder {
  color: rgba(0, 0, 0, 0.4);
}
::v-deep .el-form-item__error {
  font-family: PingFangSC;
}
.self {
  ::v-deep .el-input__inner {
  }
}
::v-deep .el-select-dropdown {
  position: absolute !important;
  top: 36px !important;
  left: 0px !important;
}
::v-deep .el-select-dropdown__wrap {
  overflow: auto !important;
}
</style>
